=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-03-21 04:39:51 +0000
+++ bzrlib/builtins.py	2007-03-26 09:59:49 +0000
@@ -148,7 +148,7 @@
     unknown
         Not versioned and not matching an ignore pattern.
 
-    To see ignored files use 'bzr ignored'.  For details in the
+    To see ignored files use 'bzr ignored'.  For details on the
     changes to file texts, use 'bzr diff'.
     
     --short gives a status flags for each item, similar to the SVN's status
@@ -183,7 +183,8 @@
     # TODO: --no-recurse, --recurse options
     
     takes_args = ['file*']
-    takes_options = ['show-ids', 'revision', 'short',
+    takes_options = ['show-ids', 'revision',
+                     Option('short', help='Give short SVN-style status lines'),
                      Option('versioned', help='Only show versioned files')]
     aliases = ['st', 'stat']
 
@@ -917,10 +918,6 @@
     out of date [so you cannot commit] but it may be useful (i.e. to examine old
     code.)
 
-    --basis is to speed up checking out from remote branches.  When specified, it
-    uses the inventory and file contents from the basis branch in preference to the
-    branch being checked out.
-
     See "help checkouts" for more information on checkouts.
     """
     takes_args = ['branch_location?', 'to_location?']
@@ -1213,8 +1210,8 @@
 
     If there is a repository in a parent directory of the location, then 
     the history of the branch will be stored in the repository.  Otherwise
-    init creates a standalone branch which carries its own history in 
-    .bzr.
+    init creates a standalone branch which carries its own history in
+    the .bzr directory.
 
     If there is already a branch at the location but it has no working tree,
     the tree can be populated with 'bzr checkout'.
@@ -1917,7 +1914,7 @@
 
 
 class cmd_export(Command):
-    """Export past revision to destination directory.
+    """Export current or past revision to a destination directory or archive.
 
     If no revision is specified this exports the last committed revision.
 
@@ -1928,7 +1925,7 @@
     Root may be the top directory for tar, tgz and tbz2 formats. If none
     is given, the top directory will be the root name of the file.
 
-    If branch is omitted then the branch containing the CWD will be used.
+    If branch is omitted then the branch containing the current working directory will be used.
 
     Note: export of tree with non-ascii filenames to zip is not supported.
 
@@ -1966,7 +1963,12 @@
 
 
 class cmd_cat(Command):
-    """Write a file's text from a previous revision."""
+    """Write the contents of a file as of a given revision to standard output.
+
+    If no revision is nominated, the last revision is used.
+
+    Take care to redirect standard output when using this command on a binary file. 
+    """
 
     takes_options = ['revision', 'name-from-revision']
     takes_args = ['filename']
@@ -2468,8 +2470,6 @@
     
     merge refuses to run if there are any uncommitted changes, unless
     --force is given.
-
-    The following merge types are available:
     """
     takes_args = ['branch?']
     takes_options = ['revision', 'force', 'merge-type', 'reprocess', 'remember',
@@ -2634,8 +2634,7 @@
     $ bzr remerge --merge-type weave --reprocess foobar
         Re-do the merge of "foobar", using the weave merge algorithm, with
         additional processing to reduce the size of conflict regions.
-    
-    The following merge types are available:"""
+    """
     takes_args = ['file*']
     takes_options = ['merge-type', 'reprocess',
                      Option('show-base', help="Show base revision text in "

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2006-12-19 08:45:03 +0000
+++ bzrlib/bundle/commands.py	2007-03-26 09:59:49 +0000
@@ -86,10 +86,13 @@
 
     bzr bundle-revisions
         - Generate a bundle relative to a remembered location
+
     bzr bundle-revisions BASE
         - Bundle to apply the current tree into BASE
+
     bzr bundle-revisions --revision A
         - Bundle to apply revision A to remembered location 
+
     bzr bundle-revisions --revision A..B
         - Bundle to transform A into B
     """

=== modified file 'bzrlib/cmd_version_info.py'
--- bzrlib/cmd_version_info.py	2006-10-06 07:00:57 +0000
+++ bzrlib/cmd_version_info.py	2007-03-26 09:59:49 +0000
@@ -45,7 +45,7 @@
 
 
 class cmd_version_info(Command):
-    """Generate version information about this tree."""
+    """Show version information about this tree."""
 
     takes_options = [Option('format', type=_parse_version_info_format,
                             help='Select the output format'),

=== modified file 'bzrlib/help_topics.py'
--- bzrlib/help_topics.py	2007-02-07 22:31:07 +0000
+++ bzrlib/help_topics.py	2007-03-26 09:59:49 +0000
@@ -190,7 +190,7 @@
 branch, which could be slow if a network connection is involved. Also, as you
 don't have a local branch, then you cannot commit locally.
 
-Lightwieght checkouts work best when you have fast reliable access to the
+Lightweight checkouts work best when you have fast reliable access to the
 master branch. This means that if the master branch is on the same disk or LAN
 a lightweight checkout will be faster than a heavyweight one for any commands
 that modify the revision history (as only one copy branch needs to be updated).

=== modified file 'tools/doc_generate/autodoc_man.py'
--- tools/doc_generate/autodoc_man.py	2007-03-06 00:10:57 +0000
+++ tools/doc_generate/autodoc_man.py	2007-03-26 09:59:49 +0000
@@ -176,7 +176,7 @@
 .I "BZRPATH"
 Path where
 .B "%(bzrcmd)s"
-is to look for external command.
+is to look for shell plugin external commands.
 .TP
 .I "BZR_EMAIL"
 E-Mail address of the user. Overrides default user config.
@@ -198,7 +198,7 @@
 .SH "FILES"
 .TP
 .I "~/.bazaar/bazaar.conf"
-Contains the users default configuration. The section
+Contains the user's default configuration. The section
 .B [DEFAULT]
 is used to define general configuration that will be applied everywhere.
 The section

